@@ -34,7 +34,7 @@ use Composer\Package\BasePackage;
  * @author Joshua Estes <Joshua.Estes@iostudio.com>
  * @author Jordi Boggiano <j.boggiano@seld.be>
  */
-class ConfigCommand extends BaseCommand
+class ConfigCommand extends BaseConfigCommand
 {
     /**
      * List of additional configurable package-properties
@@ -56,21 +56,6 @@ class ConfigCommand extends BaseCommand
         'extra',
     ];
 
-    /**
-     * @var Config
-     */
-    protected $config;
-
-    /**
-     * @var JsonFile
-     */
-    protected $configFile;
-
-    /**
-     * @var JsonConfigSource
-     */
-    protected $configSource;
-
     /**
      * @var JsonFile
      */
@@ -129,9 +114,9 @@ To remove a repository (repo is a short alias for repositories):
 
     <comment>%command.full_name% --unset repo.foo</comment>
 
-To disable packagist:
+To disable packagist.org:
 
-    <comment>%command.full_name% repo.packagist false</comment>
+    <comment>%command.full_name% repo.packagist.org false</comment>
 
 You can alter repositories in the global config.json file by passing in the
 <info>--global</info> option.
@@ -176,52 +161,17 @@ EOT
     {
         parent::initialize($input, $output);
 
-        if ($input->getOption('global') && null !== $input->getOption('file')) {
-            throw new \RuntimeException('--file and --global can not be combined');
-        }
-
-        $io = $this->getIO();
-        $this->config = Factory::createConfig($io);
-
-        // When using --global flag, set baseDir to home directory for correct absolute path resolution
-        if ($input->getOption('global')) {
-            $this->config->setBaseDir($this->config->get('home'));
-        }
-
-        $configFile = $this->getComposerConfigFile($input, $this->config);
-
-        // Create global composer.json if this was invoked using `composer global config`
-        if (
-            ($configFile === 'composer.json' || $configFile === './composer.json')
-            && !file_exists($configFile)
-            && realpath(Platform::getCwd()) === realpath($this->config->get('home'))
-        ) {
-            file_put_contents($configFile, "{\n}\n");
-        }
-
-        $this->configFile = new JsonFile($configFile, null, $io);
-        $this->configSource = new JsonConfigSource($this->configFile);
-
         $authConfigFile = $this->getAuthConfigFile($input, $this->config);
 
-        $this->authConfigFile = new JsonFile($authConfigFile, null, $io);
+        $this->authConfigFile = new JsonFile($authConfigFile, null, $this->getIO());
         $this->authConfigSource = new JsonConfigSource($this->authConfigFile, true);
 
         // Initialize the global file if it's not there, ignoring any warnings or notices
-        if ($input->getOption('global') && !$this->configFile->exists()) {
-            touch($this->configFile->getPath());
-            $this->configFile->write(['config' => new \ArrayObject]);
-            Silencer::call('chmod', $this->configFile->getPath(), 0600);
-        }
         if ($input->getOption('global') && !$this->authConfigFile->exists()) {
             touch($this->authConfigFile->getPath());
-            $this->authConfigFile->write(['bitbucket-oauth' => new \ArrayObject, 'github-oauth' => new \ArrayObject, 'gitlab-oauth' => new \ArrayObject, 'gitlab-token' => new \ArrayObject, 'http-basic' => new \ArrayObject, 'bearer' => new \ArrayObject]);
+            $this->authConfigFile->write(['bitbucket-oauth' => new \ArrayObject, 'github-oauth' => new \ArrayObject, 'gitlab-oauth' => new \ArrayObject, 'gitlab-token' => new \ArrayObject, 'http-basic' => new \ArrayObject, 'bearer' => new \ArrayObject, 'forgejo-token' => new \ArrayObject()]);
             Silencer::call('chmod', $this->authConfigFile->getPath(), 0600);
         }
-
-        if (!$this->configFile->exists()) {
-            throw new \RuntimeException(sprintf('File "%s" cannot be found in the current directory', $configFile));
-        }
     }
 
     /**
@@ -472,6 +422,7 @@ EOT
             'classmap-authoritative' => [$booleanValidator, $booleanNormalizer],
             'apcu-autoloader' => [$booleanValidator, $booleanNormalizer],
             'prepend-autoloader' => [$booleanValidator, $booleanNormalizer],
+            'update-with-minimal-changes' => [$booleanValidator, $booleanNormalizer],
             'disable-tls' => [$booleanValidator, $booleanNormalizer],
             'secure-http' => [$booleanValidator, $booleanNormalizer],
             'bump-after-update' => [
@@ -843,7 +794,7 @@ EOT
         }
 
         // handle auth
-        if (Preg::isMatch('/^(bitbucket-oauth|github-oauth|gitlab-oauth|gitlab-token|http-basic|bearer)\.(.+)/', $settingKey, $matches)) {
+        if (Preg::isMatch('/^(bitbucket-oauth|github-oauth|gitlab-oauth|gitlab-token|http-basic|custom-headers|bearer|forgejo-token)\.(.+)/', $settingKey, $matches)) {
             if ($input->getOption('unset')) {
                 $this->authConfigSource->removeConfigSetting($matches[1].'.'.$matches[2]);
                 $this->configSource->removeConfigSetting($matches[1].'.'.$matches[2]);
@@ -872,6 +823,34 @@ EOT
                 }
                 $this->configSource->removeConfigSetting($matches[1].'.'.$matches[2]);
                 $this->authConfigSource->addConfigSetting($matches[1].'.'.$matches[2], ['username' => $values[0], 'password' => $values[1]]);
+            } elseif ($matches[1] === 'custom-headers') {
+                if (count($values) === 0) {
+                    throw new \RuntimeException('Expected at least one argument (header), got none');
+                }
+
+                // Validate headers format
+                $formattedHeaders = [];
+                foreach ($values as $header) {
+                    if (!is_string($header)) {
+                        throw new \RuntimeException('Headers must be strings in "Header-Name: Header-Value" format');
+                    }
+
+                    // Check if the header is in correct "Name: Value" format
+                    if (!Preg::isMatch('/^[^:]+:\s*.+$/', $header, $headerParts)) {
+                        throw new \RuntimeException('Header "' . $header . '" is not in "Header-Name: Header-Value" format');
+                    }
+
+                    $formattedHeaders[] = $header;
+                }
+
+                $this->configSource->removeConfigSetting($matches[1].'.'.$matches[2]);
+                $this->authConfigSource->addConfigSetting($matches[1].'.'.$matches[2], $formattedHeaders);
+            } elseif ($matches[1] === 'forgejo-token') {
+                if (2 !== count($values)) {
+                    throw new \RuntimeException('Expected two arguments (username, access token), got '.count($values));
+                }
+                $this->configSource->removeConfigSetting($matches[1].'.'.$matches[2]);
+                $this->authConfigSource->addConfigSetting($matches[1].'.'.$matches[2], ['username' => $values[0], 'token' => $values[1]]);
             }
 
             return 0;
@@ -1006,29 +985,6 @@ EOT
         }
     }
 
-    /**
-     * Get the local composer.json, global config.json, or the file passed by the user
-     */
-    private function getComposerConfigFile(InputInterface $input, Config $config): string
-    {
-        return $input->getOption('global')
-            ? ($config->get('home') . '/config.json')
-            : ($input->getOption('file') ?: Factory::getComposerFile())
-        ;
-    }
-
-    /**
-     * Get the local auth.json or global auth.json, or if the user passed in a file to use,
-     * the corresponding auth.json
-     */
-    private function getAuthConfigFile(InputInterface $input, Config $config): string
-    {
-        return $input->getOption('global')
-            ? ($config->get('home') . '/auth.json')
-            : dirname($this->getComposerConfigFile($input, $config)) . '/auth.json'
-        ;
-    }
-
     /**
      * Suggest setting-keys, while taking given options in account.
      */
