@@ -61,6 +61,7 @@ class Config
         'classmap-authoritative' => false,
         'apcu-autoloader' => false,
         'prepend-autoloader' => true,
+        'update-with-minimal-changes' => false,
         'github-domains' => ['github.com'],
         'bitbucket-expose-hostname' => true,
         'disable-tls' => false,
@@ -84,8 +85,12 @@ class Config
         'gitlab-token' => [],
         'http-basic' => [],
         'bearer' => [],
+        'custom-headers' => [],
         'bump-after-update' => false,
         'allow-missing-requirements' => false,
+        'client-certificate' => [],
+        'forgejo-domains' => ['codeberg.org'],
+        'forgejo-token' => [],
     ];
 
     /** @var array<string, mixed> */
@@ -191,7 +196,7 @@ class Config
         // override defaults with given config
         if (!empty($config['config']) && is_array($config['config'])) {
             foreach ($config['config'] as $key => $val) {
-                if (in_array($key, ['bitbucket-oauth', 'github-oauth', 'gitlab-oauth', 'gitlab-token', 'http-basic', 'bearer'], true) && isset($this->config[$key])) {
+                if (in_array($key, ['bitbucket-oauth', 'github-oauth', 'gitlab-oauth', 'gitlab-token', 'http-basic', 'bearer', 'client-certificate', 'forgejo-token'], true) && isset($this->config[$key])) {
                     $this->config[$key] = array_merge($this->config[$key], $val);
                     $this->setSourceOfConfigValue($val, $key, $source);
                 } elseif (in_array($key, ['allow-plugins'], true) && isset($this->config[$key]) && is_array($this->config[$key]) && is_array($val)) {
@@ -240,6 +245,7 @@ class Config
             $newRepos = array_reverse($config['repositories'], true);
             foreach ($newRepos as $name => $repository) {
                 // disable a repository by name
+                // this is a code path, that will be used less as the next check will be preferred
                 if (false === $repository) {
                     $this->disableRepoByName((string) $name);
                     continue;
@@ -258,7 +264,11 @@ class Config
 
                 // store repo
                 if (is_int($name)) {
-                    $this->repositories[] = $repository;
+                    if (!isset($this->repositories[$name])) {
+                        $this->repositories[$name] = $repository;
+                    } else {
+                        $this->repositories[] = $repository;
+                    }
                     $this->setSourceOfConfigValue($repository, 'repositories.' . array_search($repository, $this->repositories, true), $source);
                 } else {
                     if ($name === 'packagist') { // BC support for default "packagist" named repo
@@ -592,7 +602,6 @@ class Config
     /**
      * Validates that the passed URL is allowed to be used by current config, or throws an exception.
      *
-     * @param IOInterface $io
      * @param mixed[]     $repoOptions
      */
     public function prohibitUrlByConfig(string $url, ?IOInterface $io = null, array $repoOptions = []): void
