@@ -153,6 +153,9 @@ class PoolBuilder
     /** @var int */
     private $indexCounter = 0;
 
+    /** @var ?SecurityAdvisoryPoolFilter */
+    private $securityAdvisoryPoolFilter;
+
     /**
      * @param int[] $acceptableStabilities array of stability => BasePackage::STABILITY_* value
      * @phpstan-param array<key-of<BasePackage::STABILITIES>, BasePackage::STABILITY_*> $acceptableStabilities
@@ -164,7 +167,7 @@ class PoolBuilder
      * @phpstan-param array<string, string> $rootReferences
      * @param array<string, ConstraintInterface> $temporaryConstraints Runtime temporary constraints that will be used to filter packages
      */
-    public function __construct(array $acceptableStabilities, array $stabilityFlags, array $rootAliases, array $rootReferences, IOInterface $io, ?EventDispatcher $eventDispatcher = null, ?PoolOptimizer $poolOptimizer = null, array $temporaryConstraints = [])
+    public function __construct(array $acceptableStabilities, array $stabilityFlags, array $rootAliases, array $rootReferences, IOInterface $io, ?EventDispatcher $eventDispatcher = null, ?PoolOptimizer $poolOptimizer = null, array $temporaryConstraints = [], ?SecurityAdvisoryPoolFilter $securityAdvisoryPoolFilter = null)
     {
         $this->acceptableStabilities = $acceptableStabilities;
         $this->stabilityFlags = $stabilityFlags;
@@ -174,6 +177,7 @@ class PoolBuilder
         $this->poolOptimizer = $poolOptimizer;
         $this->io = $io;
         $this->temporaryConstraints = $temporaryConstraints;
+        $this->securityAdvisoryPoolFilter = $securityAdvisoryPoolFilter;
     }
 
     /**
@@ -346,6 +350,9 @@ class PoolBuilder
 
         $this->io->debug('Built pool.');
 
+        // filter vulnerable packages before optimizing the pool otherwise we may end up with inconsistent state where the optimizer took away versions
+        // that were not vulnerable and now suddenly the vulnerable ones are removed and we are missing some versions to make it solvable
+        $pool = $this->runSecurityAdvisoryFilter($pool, $repositories);
         $pool = $this->runOptimizer($request, $pool);
 
         Intervals::clear();
@@ -806,4 +813,37 @@ class PoolBuilder
 
         return $pool;
     }
+
+    /**
+     * @param RepositoryInterface[] $repositories
+     */
+    private function runSecurityAdvisoryFilter(Pool $pool, array $repositories): Pool
+    {
+        if (null === $this->securityAdvisoryPoolFilter) {
+            return $pool;
+        }
+
+        $this->io->debug('Running security advisory pool filter.');
+
+        $before = microtime(true);
+        $total = \count($pool->getPackages());
+
+        $pool = $this->securityAdvisoryPoolFilter->filter($pool, $repositories);
+
+        $filtered = $total - \count($pool->getPackages());
+
+        if (0 === $filtered) {
+            return $pool;
+        }
+
+        $this->io->write(sprintf('Security advisory pool filter completed in %.3f seconds', microtime(true) - $before), true, IOInterface::VERY_VERBOSE);
+        $this->io->write(sprintf(
+            '<info>Found %s package versions referenced in your dependency graph. %s (%d%%) were filtered away.</info>',
+            number_format($total),
+            number_format($filtered),
+            round(100 / $total * $filtered)
+        ), true, IOInterface::VERY_VERBOSE);
+
+        return $pool;
+    }
 }
