@@ -15,7 +15,6 @@ namespace Composer\Test\Command;
 use Composer\Package\Link;
 use Composer\Semver\Constraint\MatchAllConstraint;
 use Composer\Test\TestCase;
-use InvalidArgumentException;
 
 class UpdateCommandTest extends TestCase
 {
@@ -145,10 +144,10 @@ Package operations: 2 installs, 0 updates, 0 removals
 Bumping dependencies
 <warning>Warning: Bumping dependency constraints is not recommended for libraries as it will narrow down your dependencies and may cause problems for your users.</warning>
 <warning>If your package is not a library, you can explicitly specify the "type" by using "composer config type project".</warning>
-<warning>Alternatively you can use --dev-only to only bump dependencies within "require-dev".</warning>
+<warning>Alternatively you can use --bump-after-update=dev to only bump dependencies within "require-dev".</warning>
 No requirements to update in ./composer.json.
 OUTPUT
-            , true
+            , true,
         ];
 
         yield 'update & bump with lock' => [
@@ -161,7 +160,7 @@ Nothing to modify in lock file
 Installing dependencies from lock file (including require-dev)
 Nothing to install, update or remove
 OUTPUT
-            , true
+            , true,
         ];
 
         yield 'update & bump dev only' => [
@@ -180,7 +179,7 @@ Package operations: 2 installs, 0 updates, 0 removals
 Bumping dependencies
 No requirements to update in ./composer.json.
 OUTPUT
-            , true
+            , true,
         ];
 
         yield 'update & dump with failing update' => [
