@@ -12,10 +12,16 @@
 
 namespace Composer\Test\Downloader;
 
+use Composer\Autoload\AutoloadGenerator;
 use Composer\Downloader\FileDownloader;
 use Composer\EventDispatcher\EventDispatcher;
+use Composer\IO\NullIO;
 use Composer\Plugin\PluginEvents;
 use Composer\Plugin\PreFileDownloadEvent;
+use Composer\Repository\InstalledArrayRepository;
+use Composer\Repository\RepositoryManager;
+use Composer\Test\Mock\HttpDownloaderMock;
+use Composer\Test\Mock\InstallationManagerMock;
 use Composer\Test\TestCase;
 use Composer\Util\Filesystem;
 use Composer\Util\Http\Response;
@@ -34,10 +40,7 @@ class FileDownloaderTest extends TestCase
     }
 
     /**
-     * @param \Composer\EventDispatcher\EventDispatcher $eventDispatcher
-     * @param \Composer\Cache $cache
      * @param \Composer\Util\HttpDownloader&\PHPUnit\Framework\MockObject\MockObject $httpDownloader
-     * @param \Composer\Util\Filesystem $filesystem
      */
     protected function getDownloader(?\Composer\IO\IOInterface $io = null, ?Config $config = null, ?EventDispatcher $eventDispatcher = null, ?\Composer\Cache $cache = null, $httpDownloader = null, ?Filesystem $filesystem = null): FileDownloader
     {
@@ -156,6 +159,9 @@ class FileDownloaderTest extends TestCase
         $composer = new Composer;
         $composer->setPackage($rootPackage);
         $composer->setConfig($config);
+        $composer->setRepositoryManager($rm = new RepositoryManager(new NullIO(), $config, new HttpDownloaderMock()));
+        $rm->setLocalRepository(new InstalledArrayRepository([]));
+        $composer->setInstallationManager(new InstallationManagerMock());
 
         $expectedUrl = 'foobar';
         $expectedCacheKey = 'dummy/pkg/'.hash('sha1', $expectedUrl).'.';
@@ -168,6 +174,7 @@ class FileDownloaderTest extends TestCase
         $dispatcher->addListener(PluginEvents::PRE_FILE_DOWNLOAD, static function (PreFileDownloadEvent $event) use ($expectedUrl): void {
             $event->setProcessedUrl($expectedUrl);
         });
+        $composer->setAutoloadGenerator(new AutoloadGenerator($dispatcher));
 
         $cacheMock = $this->getMockBuilder('Composer\Cache')
             ->disableOriginalConstructor()
@@ -175,7 +182,7 @@ class FileDownloaderTest extends TestCase
         $cacheMock
             ->expects($this->any())
             ->method('copyTo')
-            ->will($this->returnCallback(function ($cacheKey) use ($expectedCacheKey): bool {
+            ->will($this->returnCallback(static function ($cacheKey) use ($expectedCacheKey): bool {
                 self::assertEquals($expectedCacheKey, $cacheKey, 'Failed assertion on $cacheKey argument of Cache::copyTo method:');
 
                 return false;
@@ -183,7 +190,7 @@ class FileDownloaderTest extends TestCase
         $cacheMock
             ->expects($this->any())
             ->method('copyFrom')
-            ->will($this->returnCallback(function ($cacheKey) use ($expectedCacheKey): bool {
+            ->will($this->returnCallback(static function ($cacheKey) use ($expectedCacheKey): bool {
                 self::assertEquals($expectedCacheKey, $cacheKey, 'Failed assertion on $cacheKey argument of Cache::copyFrom method:');
 
                 return false;
@@ -193,7 +200,7 @@ class FileDownloaderTest extends TestCase
         $httpDownloaderMock
             ->expects($this->any())
             ->method('addCopy')
-            ->will($this->returnCallback(function ($url) use ($expectedUrl) {
+            ->will($this->returnCallback(static function ($url) use ($expectedUrl) {
                 self::assertEquals($expectedUrl, $url, 'Failed assertion on $url argument of HttpDownloader::addCopy method:');
 
                 return \React\Promise\resolve(
@@ -239,6 +246,9 @@ class FileDownloaderTest extends TestCase
         $composer = new Composer;
         $composer->setPackage($rootPackage);
         $composer->setConfig($config);
+        $composer->setRepositoryManager($rm = new RepositoryManager(new NullIO(), $config, new HttpDownloaderMock()));
+        $rm->setLocalRepository(new InstalledArrayRepository([]));
+        $composer->setInstallationManager(new InstallationManagerMock());
 
         $expectedUrl = 'url';
         $customCacheKey = 'xyzzy';
@@ -252,6 +262,7 @@ class FileDownloaderTest extends TestCase
         $dispatcher->addListener(PluginEvents::PRE_FILE_DOWNLOAD, static function (PreFileDownloadEvent $event) use ($customCacheKey): void {
             $event->setCustomCacheKey($customCacheKey);
         });
+        $composer->setAutoloadGenerator(new AutoloadGenerator($dispatcher));
 
         $cacheMock = $this->getMockBuilder('Composer\Cache')
             ->disableOriginalConstructor()
@@ -259,7 +270,7 @@ class FileDownloaderTest extends TestCase
         $cacheMock
             ->expects($this->any())
             ->method('copyTo')
-            ->will($this->returnCallback(function ($cacheKey) use ($expectedCacheKey): bool {
+            ->will($this->returnCallback(static function ($cacheKey) use ($expectedCacheKey): bool {
                 self::assertEquals($expectedCacheKey, $cacheKey, 'Failed assertion on $cacheKey argument of Cache::copyTo method:');
 
                 return false;
@@ -267,7 +278,7 @@ class FileDownloaderTest extends TestCase
         $cacheMock
             ->expects($this->any())
             ->method('copyFrom')
-            ->will($this->returnCallback(function ($cacheKey) use ($expectedCacheKey): bool {
+            ->will($this->returnCallback(static function ($cacheKey) use ($expectedCacheKey): bool {
                 self::assertEquals($expectedCacheKey, $cacheKey, 'Failed assertion on $cacheKey argument of Cache::copyFrom method:');
 
                 return false;
@@ -277,7 +288,7 @@ class FileDownloaderTest extends TestCase
         $httpDownloaderMock
             ->expects($this->any())
             ->method('addCopy')
-            ->will($this->returnCallback(function ($url) use ($expectedUrl) {
+            ->will($this->returnCallback(static function ($url) use ($expectedUrl) {
                 self::assertEquals($expectedUrl, $url, 'Failed assertion on $url argument of HttpDownloader::addCopy method:');
 
                 return \React\Promise\resolve(
